package com.ruoyi.zongzhi.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import io.swagger.annotations.Api;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.zongzhi.domain.TcZhongdianEnterprise;
import com.ruoyi.zongzhi.service.ITcZhongdianEnterpriseService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 重点企业名录Controller
 * 
 * @author ruoyi
 * @date 2023-08-10
 */
@RestController
@RequestMapping("/zongzhi/enterprise")
@Api(tags = "重点企业名录")
public class TcZhongdianEnterpriseController extends BaseController
{
    @Autowired
    private ITcZhongdianEnterpriseService tcZhongdianEnterpriseService;

    /**
     * 查询重点企业名录列表
     */

    @GetMapping("/list")
    public TableDataInfo list(TcZhongdianEnterprise tcZhongdianEnterprise)
    {
        startPage();
        List<TcZhongdianEnterprise> list = tcZhongdianEnterpriseService.selectTcZhongdianEnterpriseList(tcZhongdianEnterprise);
        return getDataTable(list);
    }

    /**
     * 导出重点企业名录列表
     */


    @PostMapping("/export")
    public void export(HttpServletResponse response, TcZhongdianEnterprise tcZhongdianEnterprise)
    {
        List<TcZhongdianEnterprise> list = tcZhongdianEnterpriseService.selectTcZhongdianEnterpriseList(tcZhongdianEnterprise);
        ExcelUtil<TcZhongdianEnterprise> util = new ExcelUtil<TcZhongdianEnterprise>(TcZhongdianEnterprise.class);
        util.exportExcel(response, list, "重点企业名录数据");
    }

    /**
     * 获取重点企业名录详细信息
     */

    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcZhongdianEnterpriseService.selectTcZhongdianEnterpriseById(id));
    }

    /**
     * 新增重点企业名录
     */

    @PostMapping
    public AjaxResult add(@RequestBody TcZhongdianEnterprise tcZhongdianEnterprise)
    {
        tcZhongdianEnterprise.setIsStatus(true);
        return toAjax(tcZhongdianEnterpriseService.insertTcZhongdianEnterprise(tcZhongdianEnterprise));
    }

    /**
     * 修改重点企业名录
     */

    @PutMapping
    public AjaxResult edit(@RequestBody TcZhongdianEnterprise tcZhongdianEnterprise)
    {
        return toAjax(tcZhongdianEnterpriseService.updateTcZhongdianEnterprise(tcZhongdianEnterprise));
    }

    /**
     * 删除重点企业名录
     */

	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcZhongdianEnterpriseService.deleteTcZhongdianEnterpriseByIds(ids));
    }
}
